@@ -1,15 +1,15 @@
 #' @templateVar name_model_full BG/NBD
 #' @templateVar name_class_clvmodel clv.model.bgnbd.static.cov
-#' @template template_class_clvfittedmodels_staticcov
+#' @template template_class_clvfittedtransactionmodels_staticcov
 #'
 #' @template template_slot_bgnbdcbs
 #'
-#' @seealso \link{clv.fitted.static.cov-class}, \link{clv.model.bgnbd.static.cov-class}, \link{clv.bgnbd-class}
+#' @seealso \linkS4class{clv.fitted.transactions.static.cov}, \linkS4class{clv.model.bgnbd.static.cov}, \linkS4class{clv.bgnbd}
 #'
 #' @keywords internal
 #' @importFrom methods setClass
-#' @include class_clv_model_bgnbd_staticcov.R class_clv_data_staticcovariates.R class_clv_fitted_staticcov.R
-setClass(Class = "clv.bgnbd.static.cov", contains = "clv.fitted.static.cov",
+#' @include class_clv_model_bgnbd_staticcov.R class_clv_data_staticcovariates.R class_clv_fitted_transactions_staticcov.R
+setClass(Class = "clv.bgnbd.static.cov", contains = "clv.fitted.transactions.static.cov",
          slots = c(
            cbs = "data.table"),
 
@@ -25,6 +25,6 @@ clv.bgnbd.static.cov <- function(cl, clv.data){
   clv.model    <- clv.model.bgnbd.static.cov()
 
   return(new("clv.bgnbd.static.cov",
-             clv.fitted.static.cov(cl=cl, clv.model=clv.model, clv.data=clv.data),
+             clv.fitted.transactions.static.cov(cl=cl, clv.model=clv.model, clv.data=clv.data),
              cbs = dt.cbs.bgnbd))
 }
