@@ -14,10 +14,11 @@
 #' @slot start.params.model numeric vector of default values at original scale that should be used for the LL optimization if the user does not provide start parameters. Named with \code{names.original.params.model}.
 #' @slot optimx.defaults list of default arguments for calling \code{\link[optimx]{optimx}} with \code{do.call}. Named after the respective arguments in optimx.
 #'
-#' @seealso CLV model subclasses  \link{clv.model.pnbd.no.cov-class}, \link{clv.model.pnbd.static.cov-class}, \link{clv.model.pnbd.dynamic.cov-class}
-#' @seealso Class using its instances: \link{clv.fitted-class}
+#' @seealso CLV model subclasses with and without support for fitting with correlation \linkS4class{clv.model.with.correlation}, \linkS4class{clv.model.no.correlation}
+#' @seealso Class using its instances: \linkS4class{clv.fitted}
 #'
 #' @keywords internal
+#' @include all_generics.R
 #' @importFrom methods setClass
 setClass(Class = "clv.model", contains = "VIRTUAL",
          slots = list(
@@ -48,7 +49,7 @@ setClass(Class = "clv.model", contains = "VIRTUAL",
 # Default / fallback methods for all models --------------------------------------------------------
 
 # . clv.model.check.input.args -----------------------------------------------------------------------------
-setMethod(f = "clv.model.check.input.args", signature = signature(clv.model="clv.model"), definition = function(clv.model, clv.fitted, start.params.model, use.cor, start.param.cor, optimx.args, verbose, ...){
+setMethod(f = "clv.model.check.input.args", signature = signature(clv.model="clv.model"), definition = function(clv.model, clv.fitted, start.params.model, optimx.args, verbose, ...){
   # Example:
   # if(length(list(...)) > 0)
   #   stop("Any further parameters passed in ... are not needed for this model.", call. = FALSE)
@@ -56,9 +57,9 @@ setMethod(f = "clv.model.check.input.args", signature = signature(clv.model="clv
 })
 
 # . clv.model.put.estimation.input -----------------------------------------------------------------------------
-setMethod(f = "clv.model.put.estimation.input", signature = signature(clv.model="clv.model"), definition = function(clv.model, clv.fitted, verbose, ...){
+setMethod(f = "clv.model.put.estimation.input", signature = signature(clv.model="clv.model"), definition = function(clv.model, ...){
   # Example: do nothing
-  # return(clv.fitted)
+  # return(clv.model)
   stop("The method clv.model.put.estimation.input has not been implemented by this model!")
 })
 
@@ -78,7 +79,7 @@ setMethod("clv.model.backtransform.estimated.params.model", signature = signatur
 })
 
 # . clv.model.prepare.optimx.args -----------------------------------------------------------------------------
-setMethod(f = "clv.model.prepare.optimx.args", signature = signature(clv.model="clv.model"), definition = function(clv.model, clv.fitted, prepared.optimx.args,...){
+setMethod(f = "clv.model.prepare.optimx.args", signature = signature(clv.model="clv.model"), definition = function(clv.model, clv.fitted, prepared.optimx.args){
   stop("The method clv.model.prepare.optimx.args has not been implemented by this model!")
 })
 
@@ -118,9 +119,9 @@ setMethod(f = "clv.model.vcov.jacobi.diag", signature = signature(clv.model="clv
   stop("The method clv.model.vcov.jacobi.diag has not been implemented by this model!")
 })
 
-# . clv.model.predict.clv ------------------------------------------------------------------------------------------
-setMethod("clv.model.predict.clv", signature(clv.model="clv.model"), definition = function(clv.model, clv.fitted, dt.prediction, continuous.discount.factor, verbose){
-  stop("The method clv.model.predict.clv has not been implemented by this model!")
+# . clv.model.predict ------------------------------------------------------------------------------------------
+setMethod("clv.model.predict", signature(clv.model="clv.model"), definition = function(clv.model, clv.fitted, dt.predictions, verbose, continuous.discount.factor, ...){
+  stop("The method clv.model.predict has not been implemented by this model!")
 })
 
 # . clv.model.expectation ------------------------------------------------------------------------------------------
@@ -128,9 +129,9 @@ setMethod("clv.model.expectation", signature(clv.model="clv.model"), definition
   stop("The method clv.model.expectation has not been implemented by this model!")
 })
 
-# . clv.model.put.newdata ------------------------------------------------------------------------------------------
-setMethod("clv.model.put.newdata", signature(clv.model="clv.model"), definition = function(clv.model, clv.fitted, user.newdata, verbose){
-  stop("The method clv.model.put.newdata has not been implemented by this model!")
+# . clv.model.process.newdata ------------------------------------------------------------------------------------------
+setMethod("clv.model.process.newdata", signature(clv.model="clv.model"), definition = function(clv.model, clv.fitted, user.newdata, verbose){
+  stop("The method clv.model.process.newdata has not been implemented by this model!")
 })
 
 
@@ -149,5 +150,9 @@ setMethod(f = "clv.model.backtransform.estimated.params.cov", signature = signat
   stop("The method clv.model.backtransform.estimated.params.cov has not been implemented by this model!")
 })
 
+# .clv.model.probability.density -------------------------------------------------------------------------------------------------------
+setMethod(f = "clv.model.probability.density", signature = signature(clv.model="clv.model"), definition = function(clv.model, x, clv.fitted){
+  stop("The method clv.model.probability.density has not been implemented for this model!")
+})
 
 
