@@ -10,10 +10,10 @@
 #'
 #' \code{clv.time} is a virtual class and sub-classes implement the actual parsing and calculations.
 #'
-#' \code{\link[CLVTools:clv.time.date-class]{clv.time.date}} uses data type \code{Date} for time units equal or
+#' \linkS4class{clv.time.date} uses data type \code{Date} for time units equal or
 #' greater than a single day that do not require a time of day.
 #'
-#' \code{\link[CLVTools:clv.time.datetime-class]{clv.time.datetime}} uses data type \code{POSIXct} for
+#' \linkS4class{clv.time.datetime} uses data type \code{POSIXct} for
 #' time units smaller than a single day.
 #'
 #'
@@ -26,10 +26,10 @@
 #' @slot holdout.period.in.tu Single numeric indicating the length of the holdout period in number of time units.
 #' @slot name.time.unit Single character vector storing the human-readable name of the time unit for output.
 #'
-#' @seealso \code{\link[CLVTools:summary.clv.time]{summary.clv.time}} for a summary about an object of class \code{clv.time}
-#' @seealso \code{\link[CLVTools:clv.time.days-class]{clv.time.days}} for an implementation of time unit 'Days'
-#' @seealso \code{\link[CLVTools:clv.time.weeks-class]{clv.time.weeks}} for an implementation of time unit 'Weeks'
-#' @seealso \code{\link[CLVTools:clv.time.years-class]{clv.time.years}} for an implementation of time unit 'Years'
+#' @seealso \link{summary.clv.time} for a summary about an object of class \code{clv.time}
+#' @seealso \linkS4class{clv.time.days} for an implementation of time unit 'Days'
+#' @seealso \linkS4class{clv.time.weeks} for an implementation of time unit 'Weeks'
+#' @seealso \linkS4class{clv.time.years} for an implementation of time unit 'Years'
 #'
 #'
 #' @include all_generics.R
@@ -202,7 +202,7 @@ clv.time.expectation.periods <- function(clv.time, user.tp.end){
   #   check_err_msg("The prediction end cannot be before the end of the estimation!")
 
   if(tp.expectation.end <= tp.first.period.start)
-    check_err_msg("The end cannot be before the start of the expectation period!")
+    check_err_msg("The end cannot be before the start of the estimation period!")
 
 
   if(clv.time.interval.in.number.tu(clv.time = clv.time,
