@@ -55,14 +55,9 @@ coef.clv.fitted <- function(object, ...){
   original.scale.params <- original.scale.model.params
 
   # Correlation param ---------------------------------------------------------------------------------------
-  if(object@estimation.used.correlation){
-    last.row.optimx.coef   <- tail(coef(object@optimx.estimation.output),n=1)
-    param.m                <- last.row.optimx.coef[1, object@name.prefixed.cor.param.m, drop=TRUE]
-    param.cor              <- clv.model.m.to.cor(clv.model = object@clv.model, prefixed.params.model=prefixed.params.model,
-                                                 param.m = param.m)
-    names(param.cor)       <- object@name.correlation.cor
-    original.scale.params  <- c(original.scale.params, param.cor)
-  }
+  original.scale.params <- clv.model.coef.add.correlation(clv.model = object@clv.model,
+                                                          last.row.optimx.coef = last.row.optimx.coef,
+                                                          original.scale.params = original.scale.params)
 
   return(original.scale.params)
 }
@@ -78,7 +73,7 @@ coef.clv.fitted <- function(object, ...){
 #' @description
 #' Returns the variance-covariance matrix of the parameters of the fitted model object.
 #' The variance-covariance matrix is derived from the Hessian that results from the optimization procedure.
-#' First, the Moore–Penrose generalized inverse of the Hessian is used to obtain an estimate of the
+#' First, the Moore-Penrose generalized inverse of the Hessian is used to obtain an estimate of the
 #' variance-covariance matrix.
 #' Next, because some parameters may be transformed for the purpose of restricting their value during
 #' the log-likelihood estimation, the variance estimates are adapted to
@@ -143,6 +138,7 @@ vcov.clv.fitted <- function(object, ...){
 
   # Naming and sorting
   #   Sorting:  Correct because directly from optimx hessian and for delta.diag from coef(optimx)
+  # **TODO: This might not hold if covs are transformed as well, ie need to replace their names as well (but currently covs are not transformed in any model)
   #   Naming:   Has to match coef(). model + cor: original
   #                                  any cov:     leave prefixed
   #             Change the names of model+cor to display name because
@@ -154,9 +150,9 @@ vcov.clv.fitted <- function(object, ...){
   # prefixed names to replace with original names
   names.prefixed.all <- object@clv.model@names.prefixed.params.model
   names.original.all <- object@clv.model@names.original.params.model
-  if(object@estimation.used.correlation){
-    names.prefixed.all <- c(names.prefixed.all, object@name.prefixed.cor.param.m)
-    names.original.all <- c(names.original.all, object@name.correlation.cor)
+  if(clv.model.estimation.used.correlation(object@clv.model)){
+    names.prefixed.all <- c(names.prefixed.all, object@clv.model@name.prefixed.cor.param.m)
+    names.original.all <- c(names.original.all, object@clv.model@name.correlation.cor)
   }
 
   # position of these prefixed names
@@ -218,8 +214,8 @@ confint.clv.fitted <- function(object, parm, level = 0.95, ...){
 #' @include class_clv_fitted.R
 print.clv.fitted <- function(x, digits = max(3L, getOption("digits") - 3L), ...){
   # Short print similar to lm
-  # Only print the main model coefs
-  cat(x@clv.model@name.model, " Model\n")
+
+  cat(x@clv.model@name.model, "Model\n")
 
   cat("\nCall:\n", paste(deparse(x@call), sep = "\n", collapse = "\n"), "\n", sep = "")
 
@@ -230,9 +226,11 @@ print.clv.fitted <- function(x, digits = max(3L, getOption("digits") - 3L), ...)
   cat("KKT1:", last.row.optimx$kkt1, "\n")
   cat("KKT2:", last.row.optimx$kkt2, "\n")
 
-  cat("\n")
-  cat("Used Options:\n")
-  cat("Correlation:    ", x@estimation.used.correlation, "\n")
+  if(clv.model.supports.correlation(x@clv.model)){
+    cat("\n")
+    cat("Used Options:\n")
+    cat("Correlation:    ", x@clv.model@estimation.used.correlation, "\n")
+  }
 
   invisible(x)
 }
@@ -308,9 +306,10 @@ print.summary.clv.fitted <- function(x, digits=max(3L, getOption("digits")-3L),
                        "Method" = x$method))
 
   # Correlation ------------------------------------------------------------
-  cat("\nUsed Options:")
-  .print.list(nsmall=nsmall,
-              l = x$additional.options)
+  if(length(x$additional.options)>0){
+    cat("\nUsed Options:")
+    .print.list(nsmall=nsmall, l = x$additional.options)
+  }
 
   return(invisible(x))
 }
@@ -384,7 +383,11 @@ summary.clv.fitted <- function(object, ...){
   res$method <- rownames(last.row.optimx)
 
   # Additional options: Correlation ------------------------------------------------
-  res$additional.options <- list("Correlation"=object@estimation.used.correlation)
+  if(clv.model.supports.correlation(clv.model = object@clv.model)){
+    res$additional.options <- list("Correlation"=object@clv.model@estimation.used.correlation)
+  }else{
+    res$additional.options <- list()
+  }
 
   return(res)
 }
@@ -415,7 +418,7 @@ vcov.summary.clv.fitted <- function(object, ...){
 #'
 #' @template template_details_predictionend
 #'
-#' @seealso \code{\link[CLVTools:plot.clv.fitted]{plot}} to plot the unconditional expectation
+#' @seealso \code{\link[CLVTools:plot.clv.fitted.transactions]{plot}} to plot the unconditional expectation
 #'
 #' @return
 #' A \code{data.table} which contains the following columns:
